pub struct BroadcastMsgMailbox<M: Message + Clone> { /* private fields */ }Expand description
A MsgMailbox that will send to all services that have registered with it
This mailbox allows you to do a one-to-many mapping of mailboxes to services. It’s used in the case where we need to notiy several services of the same message simultaneously.
Implementations
Sourceimpl<M: Message + Clone> BroadcastMsgMailbox<M>
impl<M: Message + Clone> BroadcastMsgMailbox<M>
pub fn send_and_forget(&self, message: M) -> Result<(), MailboxError>
pub fn send_and_wait_for_reply( &self, message: M, ) -> Result<Vec<M::Reply>, MailboxError>